====================
``searching`` module
====================

.. automodule:: whoosh.searching

Searcher class
==============

.. autoclass:: Searcher
    :members:


Results class
=============

.. autoclass:: Results
    :members:

.. autoclass:: ResultsPage
	:members:


Facets
======

.. autoclass:: Facets

